@@ -1,14 +1,14 @@
 package Module::Package::Dist::RDF;
 
 use 5.008003;
-our $VERSION = '0.001';
+our $VERSION = '0.004';
 
 package Module::Package::Dist::RDF::standard;
 
 use 5.008003;
 use strict;
-use base qw[Module::Package::Dist];
-our $VERSION = '0.001';
+use parent qw[Module::Package::Dist];
+our $VERSION = '0.004';
 
 sub _main
 {
@@ -17,4 +17,4 @@ sub _main
 	$self->mi->auto_install;
 }
 
-1;
\ No newline at end of file
+1;
